@@ -28,7 +28,6 @@
 #include <QVector>
 #include <QLocale>
 #include <QLibraryInfo>
-#include <QPixmapCache>
 #include <QFile>
 #include <QMessageBox>
 #include <QCommandLineParser>
@@ -96,6 +95,8 @@ Application::Application(int& argc, char** argv):
 
     setApplicationVersion(QStringLiteral(PCMANFM_QT_VERSION));
 
+    underWayland_ = QGuiApplication::platformName() == QStringLiteral("wayland");
+
     // QDBusConnection::sessionBus().registerObject("/org/pcmanfm/Application", this);
     QDBusConnection dbus = QDBusConnection::sessionBus();
     if(dbus.registerService(QLatin1String(serviceName))) {
@@ -236,8 +237,6 @@ bool Application::parseCommandLineArgs() {
         QString perFolderConfigFile = settings_.profileDir(profileName_) + QStringLiteral("/dir-settings.conf");
         Fm::FolderConfig::init(perFolderConfigFile.toLocal8Bit().constData());
 
-        // decrease the cache size to reduce memory usage
-        QPixmapCache::setCacheLimit(2048);
 
         if(settings_.useFallbackIconTheme()) {
             QIcon::setThemeName(settings_.fallbackIconThemeName());
@@ -337,7 +336,7 @@ void Application::init() {
     // install libfm-qt translator
     installTranslator(libFm_.translator());
 
-    // install our own tranlations
+    // install our own translations
     translator.load(QStringLiteral("pcmanfm-qt_") + QLocale::system().name(), QStringLiteral(PCMANFM_DATA_DIR) + QStringLiteral("/translations"));
     installTranslator(&translator);
 }
@@ -354,7 +353,7 @@ int Application::exec() {
 
     volumeMonitor_ = g_volume_monitor_get();
     // delay the volume manager a little because in newer versions of glib/gio there's a problem.
-    // when the first volume monitor object is created, it discovers volumes asynchonously.
+    // when the first volume monitor object is created, it discovers volumes asynchronously.
     // g_volume_monitor_get() immediately returns while the monitor is still discovering devices.
     // So initially g_volume_monitor_get_volumes() returns nothing, but shortly after that
     // we get volume-added signals for all of the volumes. This is not what we want.
@@ -990,7 +989,7 @@ void Application::onScreenDestroyed(QObject* screenObj) {
     // #40681: Regression bug: QWidget::winId() returns old value and QEvent::WinIdChange event is not emitted sometimes. (multihead setup)
     // #40791: Regression: QPlatformWindow, QWindow, and QWidget::winId() are out of sync.
     // Explanations for the workaround:
-    // Internally, Qt mantains a list of QScreens and update it when XRandR configuration changes.
+    // Internally, Qt maintains a list of QScreens and update it when XRandR configuration changes.
     // When the user turn off an monitor with xrandr --output <xxx> --off, this will destroy the QScreen
     // object which represent the output. If the QScreen being destroyed contains our panel widget,
     // Qt will call QWindow::setScreen(0) on the internal windowHandle() of our panel widget to move it
