@@ -88,6 +88,9 @@ DesktopWindow::DesktopWindow(int screenNum):
     setAttribute(Qt::WA_X11NetWmWindowTypeDesktop);
     setAttribute(Qt::WA_DeleteOnClose);
 
+    // the title can be used for setting WM rules, especially under Wayland compositors
+    setWindowTitle(QStringLiteral("pcmanfm-desktop") + QString::number(screenNum_));
+
     // set our custom file launcher
     View::setFileLauncher(&fileLauncher_);
 
@@ -100,7 +103,7 @@ DesktopWindow::DesktopWindow(int screenNum):
     // This is to workaround Qt bug 54384 which affects Qt >= 5.6
     // https://bugreports.qt.io/browse/QTBUG-54384
     // Setting a QPixmap larger then the screen resolution to desktop's QPalette won't work.
-    // So we make the viewport transparent by preventing its backround from being filled automatically.
+    // So we make the viewport transparent by preventing its background from being filled automatically.
     // Then we paint desktop's background ourselves by using its paint event handling method.
     listView_->viewport()->setAutoFillBackground(false);
 
@@ -395,7 +398,7 @@ void DesktopWindow::onTrashChanged(GFileMonitor* /*monitor*/, GFile* /*gf*/, GFi
 
 void DesktopWindow::updateTrashIcon() {
     if(listView_->isHidden()) {
-        return; // will be updated as soon as dekstop is shown
+        return; // will be updated as soon as desktop is shown
     }
     struct UpdateTrashData {
         QPointer<DesktopWindow> desktop;
@@ -890,7 +893,12 @@ void DesktopWindow::nextWallpaper() {
 }
 
 void DesktopWindow::updateFromSettings(Settings& settings, bool changeSlide) {
-    // geneeral PCManFM::View settings
+    // Sicne the layout may be changed by what follows, we need to redo our layout.
+    // We also clear the current index to set it to the visually first item.
+    selectionModel()->clearCurrentIndex();
+    queueRelayout();
+
+    // general PCManFM::View settings
     setAutoSelectionDelay(settings.singleClick() ? settings.autoSelectionDelay() : 0);
     setCtrlRightClick(settings.ctrlRightClick());
     if(proxyModel_) {
@@ -918,10 +926,6 @@ void DesktopWindow::updateFromSettings(Settings& settings, bool changeSlide) {
     setIconSize(Fm::FolderView::IconMode, QSize(settings.desktopIconSize(), settings.desktopIconSize()));
     setMargins(settings.desktopCellMargins());
     updateShortcutsFromSettings(settings);
-    // setIconSize and setMargins may trigger relayout of items by QListView, so we need to do the layout again.
-    // We also clear the current index to set it to the visually first item.
-    selectionModel()->clearCurrentIndex();
-    queueRelayout();
     setForeground(settings.desktopFgColor());
     setBackground(settings.desktopBgColor());
     setShadow(settings.desktopShadowColor());
@@ -1110,8 +1114,10 @@ void DesktopWindow::onCreatingShortcut() {
         filesToTrust_ << name;
     });
     dlg->show();
-    dlg->raise();
-    dlg->activateWindow();
+    if(!static_cast<Application*>(qApp)->underWayland()) {
+        dlg->raise();
+        dlg->activateWindow();
+    }
 }
 
 void DesktopWindow::onDesktopPreferences() {
@@ -1122,8 +1128,6 @@ void DesktopWindow::onRowsInserted(const QModelIndex& parent, int start, int end
     Q_UNUSED(parent);
     Q_UNUSED(start);
     Q_UNUSED(end);
-    // disable view updates temporarily and delay relayout to prevent items from shaking
-    listView_->setUpdatesEnabled(false);
     queueRelayout(100);
 }
 
@@ -1152,7 +1156,6 @@ void DesktopWindow::onRowsAboutToBeRemoved(const QModelIndex& parent, int start,
             storeCustomPos();
         }
     }
-    listView_->setUpdatesEnabled(false);
     queueRelayout(100);
 }
 
@@ -1393,7 +1396,7 @@ void DesktopWindow::relayoutItems() {
             // center the contents horizontally
             listView_->setPositionForIndex(pos + QPoint((itemSize.width() - itemWidth) / 2, 0), index);
 
-            // if all items should be sticky, add this item to custom postions
+            // if all items should be sticky, add this item to custom positions
             if(allSticky && pos.x() + itemSize.width() <= workArea.right() + 1) {
                 customItemPos_[name] = pos;
                 customPosStorage_[name] = pos;
@@ -1553,6 +1556,9 @@ void DesktopWindow::queueRelayout(int delay) {
     // qDebug() << "queueRelayout";
     removeBottomGap();
     if(!relayoutTimer_) {
+        if(listView_->updatesEnabled()) {
+            listView_->setUpdatesEnabled(false); // prevent items from shaking as far as possible
+        }
         relayoutTimer_ = new QTimer();
         relayoutTimer_->setSingleShot(true);
         connect(relayoutTimer_, &QTimer::timeout, this, &DesktopWindow::relayoutItems);
@@ -1886,6 +1892,10 @@ bool DesktopWindow::eventFilter(QObject* watched, QEvent* event) {
         case QEvent::Wheel:
             // removal of scrollbars is not enough to prevent scrolling
             return true;
+        case QEvent::DragLeave:
+            // remove the drop indicator on leaving the widget during DND
+            dropRect_ = QRect();
+            break;
         default:
             break;
         }
@@ -1996,35 +2006,60 @@ void DesktopWindow::childDropEvent(QDropEvent* e) {
 
         if(curIndx.isValid() && !workArea.isEmpty()) {
             QPoint curPoint = listView_->visualRect(curIndx).topLeft();
+            bool reachedLastCell = false;
+            QPoint nxtPos = dropPos;
+            std::set<std::string> droppedFiles;
 
-            // first move the current item to the drop position
+            // First move the current item to the drop position.
             auto file = proxyModel_->fileInfoFromIndex(curIndx);
             if(file) {
                 QPoint pos = dropPos;
+
                 // NOTE: DND always reports the drop position in the usual (LTR) coordinates.
                 // Therefore, to have the same calculations regardless of the layout direction,
                 // we reverse the x-coordinate with RTL.
                 if(rtl) {
                     pos.setX(width() - pos.x());
                 }
-                stickToPosition(file->name(), pos, workArea, grid);
+
+                reachedLastCell = stickToPosition(file->name(), pos,
+                                                  workArea, grid,
+                                                  droppedFiles, reachedLastCell);
+                nxtPos = pos;
+                droppedFiles.insert(file->name());
             }
 
-            // then move the other items so that their relative postions are preserved
-            const QModelIndexList selected = selectedIndexes();
-            for(const QModelIndex& indx : selected) {
+            // Then move the other items so that their relative positions are preserved.
+            QModelIndexList selected = selectedIndexes();
+            // sort the selection from left to right and top to bottom, in order to make
+            // the positions of dropped items more predictable
+            std::sort(selected.begin(), selected.end(), [this] (const QModelIndex& a, const QModelIndex& b) {
+                QPoint pa = listView_->visualRect(a).topLeft();
+                QPoint pb = listView_->visualRect(b).topLeft();
+                return (pa.x() != pb.x() ? pa.x() < pb.x() : pa.y() < pb.y());
+            });
+            for(const QModelIndex& indx : qAsConst(selected)) {
                 if(indx == curIndx) {
                     continue;
                 }
                 file = proxyModel_->fileInfoFromIndex(indx);
                 if(file) {
                     QPoint nxtDropPos = dropPos + listView_->visualRect(indx).topLeft() - curPoint;
+
                     if(rtl) { // like above
                         nxtDropPos.setX(width() - nxtDropPos.x());
                     }
-                    nxtDropPos.setX(qBound(workArea.left(), nxtDropPos.x(), workArea.right() + 1));
-                    nxtDropPos.setY(qBound(workArea.top(), nxtDropPos.y(), workArea.bottom() + 1));
-                    stickToPosition(file->name(), nxtDropPos, workArea, grid);
+
+                    if(!workArea.contains(nxtDropPos)) {
+                        // if the drop point is outside the work area, forget about
+                        // keeping relative positions and choose the next position
+                        nxtDropPos = nxtPos;
+                    }
+                    reachedLastCell = stickToPosition(file->name(), nxtDropPos,
+                                                       workArea, grid,
+                                                       droppedFiles, reachedLastCell);
+                    nxtPos = nxtDropPos;
+                    droppedFiles.insert(file->name());
                 }
             }
         }
@@ -2075,7 +2110,7 @@ void DesktopWindow::childDropEvent(QDropEvent* e) {
             }
         }
 
-        // reserve successive positions for dropped items, starting with the drop rectangle
+        // Reserve successive positions for dropped items, starting with the drop rectangle.
         if(!workArea.isEmpty()
            && mimeData->hasUrls()) {
             const QString desktopDir = XdgDir::readDesktopDir() + QString(QLatin1String("/"));
@@ -2085,16 +2120,20 @@ void DesktopWindow::childDropEvent(QDropEvent* e) {
             }
             const QList<QUrl> urlList = mimeData->urls();
             bool reachedLastCell = false;
+            std::set<std::string> droppedFiles;
             for(const QUrl& url : urlList) {
                 QString name = url.fileName();
                 if(!name.isEmpty()
                    // don't stick to the position if there is an overwrite prompt
                    && !QFile::exists(desktopDir + name)) {
-                    reachedLastCell = stickToPosition(name.toStdString(), dropPos, workArea, grid, reachedLastCell);
+                    reachedLastCell = stickToPosition(name.toStdString(), dropPos,
+                                                      workArea, grid,
+                                                      droppedFiles, reachedLastCell);
+                    droppedFiles.insert(name.toStdString());
                 }
             }
-            // wait for FolderView::dropIsDecided() to know whether the new positions should be stored
-            // on accepting the drop or the original positions should be restored on cancelling it
+            // Wait for FolderView::dropIsDecided() to know whether the new positions should be stored
+            // on accepting the drop or the original positions should be restored on cancelling it.
         }
     }
 }
@@ -2113,12 +2152,14 @@ void DesktopWindow::onDecidingDrop(bool accepted) {
 // starting from the drop point, and carries the existing sticky items with them,
 // until it reaches the last cell and then puts the remaining items in the opposite
 // direction. In this way, it creates a natural DND, especially with multiple files.
-bool DesktopWindow::stickToPosition(const std::string& file, QPoint& pos, const QRect& workArea, const QSize& grid, bool reachedLastCell) {
+bool DesktopWindow::stickToPosition(const std::string& file, QPoint& pos,
+                                    const QRect& workArea, const QSize& grid,
+                                    const std::set<std::string>& droppedFiles, bool reachedLastCell) {
     if(workArea.isEmpty()) {
         return reachedLastCell;
     }
 
-    // normalize the position, depending on the positioning direction
+    // Normalize the position, depending on the positioning direction.
     if(!reachedLastCell) { // default direction: top -> bottom, left -> right
 
         // put the drop point inside the work area to prevent unnatural jumps
@@ -2149,9 +2190,9 @@ bool DesktopWindow::stickToPosition(const std::string& file, QPoint& pos, const
         }
     }
 
-    // find if there is a sticky item at this position
+    // Find if there is a sticky item at this position.
     std::string otherFile;
-    bool isTrash = false;
+    bool skipPos = false;
     auto oldItem = std::find_if(customItemPos_.cbegin(),
                                 customItemPos_.cend(),
                                 [pos](const std::pair<std::string, QPoint>& elem) {
@@ -2159,25 +2200,30 @@ bool DesktopWindow::stickToPosition(const std::string& file, QPoint& pos, const
                                 });
     if(oldItem != customItemPos_.cend()) {
         otherFile = oldItem->first;
-        if(trashMonitor_ && otherFile != file && otherFile == "trash-can.desktop") {
-            isTrash = true; // occupied by a sticky Trash
+        if(!otherFile.empty() && otherFile != file) {
+            if(trashMonitor_ && otherFile == "trash-can.desktop") {
+                skipPos = true; // the sticky Trash
+            }
+            if(!skipPos && std::find(droppedFiles.cbegin(), droppedFiles.cend(), otherFile) != droppedFiles.cend()) {
+                skipPos = true; // an already dropped file
+            }
         }
     }
 
-    if(!isTrash) {
-        // stick to the position if it is not occupied by Trash
-        // NOTE: In this way, a sticky Trash can be moved only explicitly.
+    // Stick to the position if it is not occupied by Trash or a dropped file.
+    // NOTE: In this way, the sticky Trash will not be moved by other items.
+    if(!skipPos) {
         customItemPos_[file] = pos;
     }
 
-    // check whether we are in the last visible cell if it isn't reached already
+    // Check whether we are in the last visible cell.
     if(!reachedLastCell
        && pos.y() + 2 * grid.height() + listView_->spacing() > workArea.bottom() + 1
        && pos.x() + 2 * grid.width() + listView_->spacing() > workArea.right() + 1) {
         reachedLastCell = true;
     }
 
-    // find the next position
+    // Find the next position.
     if(reachedLastCell) {
         // when this is the last visible cell, reverse the positioning direction
         // to avoid off-screen items later
@@ -2194,13 +2240,14 @@ bool DesktopWindow::stickToPosition(const std::string& file, QPoint& pos, const
         }
     }
 
-    // if the position was ocupied by Trash, go to the next postiton
-    if(isTrash) {
-        reachedLastCell = stickToPosition(file, pos, workArea, grid, reachedLastCell);
+    // if the position was occupied by Trash or a dropped file, go to the next postiton
+    if(skipPos) {
+        reachedLastCell = stickToPosition(file, pos, workArea, grid, droppedFiles, reachedLastCell);
     }
     // but if there was another sticky item at the same position, move it to the next position
     else if(!otherFile.empty() && otherFile != file) {
-        reachedLastCell = stickToPosition(otherFile, pos, workArea, grid, reachedLastCell);
+        QPoint _pos = pos;
+        reachedLastCell = stickToPosition(otherFile, _pos, workArea, grid, droppedFiles, reachedLastCell);
     }
 
     return reachedLastCell;
